--- /home/jbez/Documents/Projects/gekkofs-dev/src/daemon/backend/data/chunk_storage.cpp	2019-09-27 15:10:05.333230628 +0200
+++ /home/jbez/Documents/Projects/gekkofs/src/daemon/backend/data/chunk_storage.cpp	2019-09-26 18:30:18.234274006 +0200
@@ -79,16 +79,26 @@
     auto chunk_dir = absolute(get_chunks_dir(file_path));
     const bfs::directory_iterator end;
 
-    for (bfs::directory_iterator chunk_file(chunk_dir); chunk_file != end; ++chunk_file) {
-        auto chunk_path = chunk_file->path();
-        auto chunk_id = std::stoul(chunk_path.filename().c_str());
-        if(chunk_id >= chunk_start && chunk_id <= chunk_end) {
-            int ret = unlink(chunk_path.c_str());
-            if(ret == -1) {
-                log->error("Failed to remove chunk file. File: {}, Error: {}", chunk_path.native(), std::strerror(errno));
-                throw std::system_error(errno, std::system_category(), "Failed to remove chunk file");
+    try {
+        bfs::directory_iterator chunk_file(chunk_dir);
+
+        for (; chunk_file != end; ++chunk_file) {
+            auto chunk_path = chunk_file->path();
+            auto chunk_id = std::stoul(chunk_path.filename().c_str());
+            if(chunk_id >= chunk_start && chunk_id <= chunk_end) {
+                int ret = unlink(chunk_path.c_str());
+                if(ret == -1) {
+                    log->error("Failed to remove chunk file. File: {}, Error: {}", chunk_path.native(), std::strerror(errno));
+                    throw std::system_error(errno, std::system_category(), "Failed to remove chunk file");
+                }
             }
         }
+    } catch (const bfs::filesystem_error& e) {
+        if (e.code() == boost::system::errc::no_such_file_or_directory) {
+            return;
+        }
+
+        throw;
     }
 }
 
